@@ -1,4 +1,4 @@
-// Copyright 2013-2023 Daniel Parker
+// Copyright 2013-2024 Daniel Parker
 // Distributed under Boost license
 
 #include <string_view>
@@ -778,7 +778,7 @@ public:
                }
                return Json(arg0.template as<double>() / arg1.template as<double>());
              }
-        );
+ );
     }
 };
 
@@ -864,177 +864,9 @@ void make_expression_with_stateful_allocator()
     std::cout << pretty_print(result) << "\n\n";
 }
 
-// since 0.172.0
-void remove_selected_books()
-{
-    std::string json_string = R"(
-{
-    "books":
-    [
-        {
-            "category": "fiction",
-            "title" : "A Wild Sheep Chase",
-            "author" : "Haruki Murakami",
-            "price" : 22.72
-        },
-        {
-            "category": "fiction",
-            "title" : "The Night Watch",
-            "author" : "Sergei Lukyanenko",
-            "price" : 23.58
-        },
-        {
-            "category": "fiction",
-            "title" : "The Comedians",
-            "author" : "Graham Greene",
-            "price" : 21.99
-        },
-        {
-            "category": "memoir",
-            "title" : "The Night Watch",
-            "author" : "Phillips, David Atlee"
-        }
-    ]
-}
-    )";
-
-    json doc = json::parse(json_string);
-
-    auto expr = jsonpath::make_expression<json>("$.books[?(@.category == 'fiction')]");
-    std::vector<jsonpath::json_location> locations = expr.select_paths(doc, 
-        jsonpath::result_options::sort_descending | jsonpath::result_options::sort_descending);
-
-    for (const auto& location : locations)
-    {
-        std::cout << jsonpath::to_string(location) << "\n";
-    }
-    std::cout << "\n";
-
-    for (const auto& location : locations)
-    {
-        jsonpath::remove(doc, location);
-    }
-
-    std::cout << jsoncons::pretty_print(doc) << "\n\n";
-}
-
-// since 0.172.0
-void remove_selected_books_in_one_step()
-{
-    std::string json_string = R"(
-{
-    "books":
-    [
-        {
-            "category": "fiction",
-            "title" : "A Wild Sheep Chase",
-            "author" : "Haruki Murakami",
-            "price" : 22.72
-        },
-        {
-            "category": "fiction",
-            "title" : "The Night Watch",
-            "author" : "Sergei Lukyanenko",
-            "price" : 23.58
-        },
-        {
-            "category": "fiction",
-            "title" : "The Comedians",
-            "author" : "Graham Greene",
-            "price" : 21.99
-        },
-        {
-            "category": "memoir",
-            "title" : "The Night Watch",
-            "author" : "Phillips, David Atlee"
-        }
-    ]
-}
-    )";
-
-    json doc = json::parse(json_string);
-
-    std::size_t n = jsonpath::remove(doc, "$.books[?(@.category == 'fiction')]");
-
-    std::cout << "Number of nodes removed: " << n << "\n\n";
-
-    std::cout << jsoncons::pretty_print(doc) << "\n\n";
-}
-
-void convert_normalized_path_to_json_pointer()
-{
-    std::string json_string = R"(
-{
-    "books":
-    [
-        {
-            "category": "fiction",
-            "title" : "A Wild Sheep Chase",
-            "author" : "Haruki Murakami",
-            "price" : 22.72
-        },
-        {
-            "category": "fiction",
-            "title" : "The Night Watch",
-            "author" : "Sergei Lukyanenko",
-            "price" : 23.58
-        },
-        {
-            "category": "fiction",
-            "title" : "The Comedians",
-            "author" : "Graham Greene",
-            "price" : 21.99
-        },
-        {
-            "category": "memoir",
-            "title" : "The Night Watch",
-            "author" : "Phillips, David Atlee"
-        }
-    ]
-}
-    )";
-
-    json doc = json::parse(json_string);
-
-    auto expr = jsonpath::make_expression<json>("$.books[?(@.category == 'fiction')]");
-    std::vector<jsonpath::json_location> locations = expr.select_paths(doc, jsonpath::result_options::sort_descending);
-
-    for (const auto& location : locations)
-    {
-        std::cout << jsonpath::to_string(location) << "\n";
-    }
-    std::cout << "\n";
-
-    std::vector<jsoncons::jsonpointer::json_pointer> pointers;
-    for (const auto& location : locations)
-    {
-        jsonpointer::json_pointer ptr;
-        {
-            for (const jsonpath::path_element& element : location)
-            {
-                if (element.has_name())
-                {
-                    ptr.append(element.name());
-                }
-                else
-                {
-                    ptr.append(element.index());
-                }
-            }
-        }
-        pointers.push_back(ptr);
-    }
-
-    for (const auto& ptr : pointers)
-    {
-        std::cout << jsonpointer::to_string(ptr) << "\n";
-    }
-    std::cout << "\n";
-}
-
 int main()
 {
-    std::cout << "\nJsonPath examples\n\n";
+    std::cout << "\njsonpath examples\n\n";
 
     jsonpath_complex_examples();
     jsonpath_union();
@@ -1067,13 +899,7 @@ int main()
     parent_operator_example();
 
     make_expression_with_stateful_allocator();
-
-    remove_selected_books();
-
-    convert_normalized_path_to_json_pointer();
-
-    remove_selected_books_in_one_step();
-
+    
     std::cout << "\n";
 }
 
