@@ -1,11 +1,11 @@
-// Copyright 2013-2023 Daniel Parker
+// Copyright 2013-2024 Daniel Parker
 // Distributed under Boost license
 
 #include <jsoncons/json.hpp>
 #include <catch/catch.hpp>
 #include <common/FreeListAllocator.hpp>
 
-#if defined(JSONCONS_HAS_POLYMORPHIC_ALLOCATOR)
+#if defined(JSONCONS_HAS_POLYMORPHIC_ALLOCATOR) && JSONCONS_HAS_POLYMORPHIC_ALLOCATOR == 1
 #include <memory_resource> 
 using namespace jsoncons;
 
