@@ -1,4 +1,4 @@
-// Copyright 2013-2023 Daniel Parker
+// Copyright 2013-2024 Daniel Parker
 // Distributed under Boost license
 
 #if defined(_MSC_VER)
@@ -137,7 +137,7 @@ TEST_CASE("n_objects_test")
 
     options.assume_header(true)
             .mapping_kind(csv::csv_mapping_kind::n_rows);
-    csv::csv_reader reader1(bond_yields,decoder,options);
+    csv::csv_string_reader reader1(bond_yields,decoder,options);
     reader1.read();
     ojson val1 = decoder.get_result();
     //std::cout << "\n(1)\n"<< pretty_print(val1) << "\n";
@@ -145,7 +145,7 @@ TEST_CASE("n_objects_test")
 
     options.assume_header(true);
     options.mapping_kind(csv::csv_mapping_kind::n_objects);
-    csv::csv_reader reader2(bond_yields,decoder,options);
+    csv::csv_string_reader reader2(bond_yields,decoder,options);
     reader2.read();
     ojson val2 = decoder.get_result();
     //std::cout << "\n(2)\n"<< pretty_print(val2) << "\n";
@@ -1501,7 +1501,7 @@ TEST_CASE("csv detect bom")
     }
 }
 /*
-#if defined(JSONCONS_HAS_STATEFUL_ALLOCATOR)
+#if defined(JSONCONS_HAS_STATEFUL_ALLOCATOR) && JSONCONS_HAS_STATEFUL_ALLOCATOR == 1
 TEST_CASE("csv_reader constructors")
 {
     const std::string input = R"(Date,1Y,2Y,3Y,5Y
