@@ -1,4 +1,4 @@
-// Copyright 2013-2023 Daniel Parker
+// Copyright 2013-2024 Daniel Parker
 // Distributed under Boost license
 
 #if defined(_MSC_VER)
@@ -503,187 +503,7 @@ TEST_CASE("[jsonpointer] create_if_missing")
     }
 }
 
-TEST_CASE("to_uri_fragment test")
-{
-    SECTION("empty")
-    {
-        std::error_code ec;
-        std::string location = "";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/foo")
-    {
-        std::error_code ec;
-        std::string location = "/foo";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/foo");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/foo/0")
-    {
-        std::error_code ec;
-        std::string location = "/foo/0";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/foo/0");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/")
-    {
-        std::error_code ec;
-        std::string location = "/";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/a~1b")
-    {
-        std::error_code ec;
-        std::string location = "/a~1b";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/a~1b");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/c%d")
-    {
-        std::error_code ec;
-        std::string location = "/c%d";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/c%25d");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/e^f")
-    {
-        std::error_code ec;
-        std::string location = "/e^f";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/e%5Ef");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/g|h")
-    {
-        std::error_code ec;
-        std::string location = "/g|h";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/g%7Ch");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/i\\j")
-    {
-        std::error_code ec;
-        std::string location = "/i\\j";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/i%5Cj");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/k\"l")
-    {
-        std::error_code ec;
-        std::string location = "/k\"l";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/k%22l");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/ ")
-    {
-        std::error_code ec;
-        std::string location = "/ ";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        CHECK(fragment == "#/%20");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/m~0n")
-    {
-        std::error_code ec;
-        std::string location = "/m~0n";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-        std::string fragment = pointer.to_uri_fragment();
-        //Debug.WriteLine($"/m~0n {fragment}");
-        CHECK(fragment == "#/m~0n");
-        pointer = jsonpointer::json_pointer::parse(fragment, ec);
-        REQUIRE_FALSE(ec);
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/foo/")
-    {
-        std::error_code ec;
-        std::string location = "/foo/";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-
-        CHECK(pointer.to_string() == location);
-    }
-
-    SECTION("/foo//bar")
-    {
-        std::error_code ec;
-        std::string location = "/foo//bar";
-        jsonpointer::json_pointer pointer = jsonpointer::json_pointer::parse(location, ec);
-        REQUIRE_FALSE(ec);
-
-        CHECK(pointer.to_string() == location);
-    }
-}
-
-#if defined(JSONCONS_HAS_STATEFUL_ALLOCATOR)
+#if defined(JSONCONS_HAS_STATEFUL_ALLOCATOR) && JSONCONS_HAS_STATEFUL_ALLOCATOR == 1
 
 #include <common/FreeListAllocator.hpp>
 
@@ -739,5 +559,30 @@ TEST_CASE("jsonpointer get with stateful allocator")
     check_get(example,"/ ", custom_json(7));
     check_get(example,"/m~0n", custom_json(8));
 }
-
 #endif
+
+TEST_CASE("jsonpointer JSON Schema tests")
+{
+    SECTION("not a valid JSON-pointer (~ not escaped)")
+    {
+        std::error_code ec;
+        auto jsonp = jsonpointer::json_pointer::parse("/foo/bar~", ec);
+        CHECK(ec);
+    }
+    SECTION("not a valid JSON-pointer (URI Fragment Identifier) #1")
+    {
+        std::error_code ec;
+        auto jsonp = jsonpointer::json_pointer::parse("#", ec);
+        std::cout << jsonp.string() << "\n";
+        CHECK(ec);
+    }
+    SECTION("not a valid JSON-pointer (some escaped, but not all) #1")
+    {
+        std::error_code ec;
+        auto jsonp = jsonpointer::json_pointer::parse("/~0~", ec);
+        std::cout << jsonp.string() << "\n";
+        CHECK(ec);
+    }
+}
+
+
